@@ -255,7 +255,7 @@ class WBEMServer(object):
     @property
     def namespaces(self):
         """
-        :class:`py:list` of :term:`string`: Names of all namespaces of the
+        list of :term:`string`: Names of all namespaces of the
         WBEM server.
 
         Raises:
@@ -270,7 +270,7 @@ class WBEMServer(object):
     @property
     def namespace_paths(self):
         """
-        :class:`py:list` of :class:`~pywbem.CIMInstanceName`: Instance paths
+        list of :class:`~pywbem.CIMInstanceName`: Instance paths
         of the CIM instances in the Interop namespace that represent the
         namespaces of the WBEM server.
 
@@ -367,7 +367,7 @@ class WBEMServer(object):
     @property
     def profiles(self):
         """
-        :class:`py:list` of :class:`~pywbem.CIMInstance`: The
+        list of :class:`~pywbem.CIMInstance`: The
         `CIM_RegisteredProfile` instances representing all management profiles
         advertised by the WBEM server.
 
@@ -669,7 +669,7 @@ class WBEMServer(object):
 
         Returns:
 
-          :class:`py:list` of :class:`~pywbem.CIMInstance`: The
+          list of :class:`~pywbem.CIMInstance`: The
           `CIM_RegisteredProfile` instances representing the filtered
           subset of the management profiles advertised by the WBEM server.
 
@@ -864,7 +864,7 @@ class WBEMServer(object):
 
         Returns:
 
-          :class:`py:list` of :class:`~pywbem.CIMInstanceName`: The instance
+          list of :class:`~pywbem.CIMInstanceName`: The instance
           paths of the central instances of the implementation of the
           management profile.
 
