@@ -183,7 +183,7 @@ function make_virtualenv()
   fi
 
   run "pip install pip $PIP_OPTS" "Reinstalling pip with PACKAGE_LEVEL=$PACKAGE_LEVEL"
-  run "pip install setuptools $PIP_OPTS" "Reinstalling setuptools with PACKAGE_LEVEL=$PACKAGE_LEVEL"
+  run "pip install setuptools $PIP_OPTS -c $(abspath $ROOT_DIR/requirements.txt)" "Reinstalling setuptools with PACKAGE_LEVEL=$PACKAGE_LEVEL and constraints from requirements.txt"
   run "pip install wheel $PIP_OPTS" "Reinstalling wheel with PACKAGE_LEVEL=$PACKAGE_LEVEL"
 
   verbose "Virtualenv before actual install test:"
@@ -471,6 +471,7 @@ function test1()
   cleanup_egg_file
 }
 
+# Install test via setup.py has been disabled
 function test2()
 {
   testcase="test2"
@@ -516,6 +517,7 @@ function test4()
   cleanup_egg_file
 }
 
+# Install test via setup.py has been disabled
 function test5()
 {
   testcase="test5"
@@ -558,7 +560,6 @@ fi
 prep
 
 test1
-test2
 test3
 test4
 
